[pacman-dev] [PATCH 3/3] Use ignoregroup rather than ignoregrp in the handle

Allan McRae allan at archlinux.org
Wed Jun 29 02:05:29 EDT 2011


This matches the naming in pacman.conf.

Signed-off-by: Allan McRae <allan at archlinux.org>
---
 lib/libalpm/handle.c  |   12 ++++++------
 lib/libalpm/handle.h  |    2 +-
 lib/libalpm/package.c |    4 ++--
 3 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/lib/libalpm/handle.c b/lib/libalpm/handle.c
index 62b2d9a..8486851 100644
--- a/lib/libalpm/handle.c
+++ b/lib/libalpm/handle.c
@@ -84,7 +84,7 @@ void _alpm_handle_free(alpm_handle_t *handle)
 	FREELIST(handle->noupgrade);
 	FREELIST(handle->noextract);
 	FREELIST(handle->ignorepkg);
-	FREELIST(handle->ignoregrp);
+	FREELIST(handle->ignoregroup);
 	FREE(handle);
 }
 
@@ -227,7 +227,7 @@ alpm_list_t SYMEXPORT *alpm_option_get_ignorepkgs(alpm_handle_t *handle)
 alpm_list_t SYMEXPORT *alpm_option_get_ignoregroups(alpm_handle_t *handle)
 {
 	CHECK_HANDLE(handle, return NULL);
-	return handle->ignoregrp;
+	return handle->ignoregroup;
 }
 
 const char SYMEXPORT *alpm_option_get_arch(alpm_handle_t *handle)
@@ -524,15 +524,15 @@ int SYMEXPORT alpm_option_remove_ignorepkg(alpm_handle_t *handle, const char *pk
 int SYMEXPORT alpm_option_add_ignoregroup(alpm_handle_t *handle, const char *grp)
 {
 	CHECK_HANDLE(handle, return -1);
-	handle->ignoregrp = alpm_list_add(handle->ignoregrp, strdup(grp));
+	handle->ignoregroup = alpm_list_add(handle->ignoregroup, strdup(grp));
 	return 0;
 }
 
 int SYMEXPORT alpm_option_set_ignoregroups(alpm_handle_t *handle, alpm_list_t *ignoregrps)
 {
 	CHECK_HANDLE(handle, return -1);
-	if(handle->ignoregrp) FREELIST(handle->ignoregrp);
-	handle->ignoregrp = alpm_list_strdup(ignoregrps);
+	if(handle->ignoregroup) FREELIST(handle->ignoregroup);
+	handle->ignoregroup = alpm_list_strdup(ignoregrps);
 	return 0;
 }
 
@@ -540,7 +540,7 @@ int SYMEXPORT alpm_option_remove_ignoregroup(alpm_handle_t *handle, const char *
 {
 	char *vdata = NULL;
 	CHECK_HANDLE(handle, return -1);
-	handle->ignoregrp = alpm_list_remove_str(handle->ignoregrp, grp, &vdata);
+	handle->ignoregroup = alpm_list_remove_str(handle->ignoregroup, grp, &vdata);
 	if(vdata != NULL) {
 		FREE(vdata);
 		return 1;
diff --git a/lib/libalpm/handle.h b/lib/libalpm/handle.h
index 4b36619..ae8c7c8 100644
--- a/lib/libalpm/handle.h
+++ b/lib/libalpm/handle.h
@@ -62,7 +62,7 @@ struct __alpm_handle_t {
 	alpm_list_t *noupgrade;   /* List of packages NOT to be upgraded */
 	alpm_list_t *noextract;   /* List of files NOT to extract */
 	alpm_list_t *ignorepkg;   /* List of packages to ignore */
-	alpm_list_t *ignoregrp;   /* List of groups to ignore */
+	alpm_list_t *ignoregroup; /* List of groups to ignore */
 
 	/* options */
 	int usesyslog;           /* Use syslog instead of logfile? */ /* TODO move to frontend */
diff --git a/lib/libalpm/package.c b/lib/libalpm/package.c
index efdf1be..31f0732 100644
--- a/lib/libalpm/package.c
+++ b/lib/libalpm/package.c
@@ -598,7 +598,7 @@ alpm_pkg_t *_alpm_pkg_find(alpm_list_t *haystack, const char *needle)
 /** Test if a package should be ignored.
  *
  * Checks if the package is ignored via IgnorePkg, or if the package is
  * in a group ignored via IgnoreGrp.
  *
  * @param handle the context handle
  * @param pkg the package to test
@@ -615,7 +615,7 @@ int _alpm_pkg_should_ignore(alpm_handle_t *handle, alpm_pkg_t *pkg)
 	}
 
 	/* next see if the package is in a group that is ignored */
-	for(groups = handle->ignoregrp; groups; groups = alpm_list_next(groups)) {
+	for(groups = handle->ignoregroup; groups; groups = alpm_list_next(groups)) {
 		char *grp = (char *)alpm_list_getdata(groups);
 		if(alpm_list_find_str(alpm_pkg_get_groups(pkg), grp)) {
 			return 1;
@@ -598,7 +598,7 @@ alpm_pkg_t *_alpm_pkg_find(alpm_list_t *haystack, const char *needle)
  *
  * Checks if the package is ignored via IgnorePkg, or if the package is
- * in a group ignored via IgnoreGrp.
+ * in a group ignored via IgnoreGroup.
  *
  * @param handle the context handle
-- 
1.7.6



More information about the pacman-dev mailing list